const mongoose = require('mongoose');
const config = require('../config/database');
const bcrypt = require('bcryptjs');

const UserSchema = mongoose.Schema({
  username: { type: String, required: true },
  name: { type: String, required: true },
  gender: { type: String, required: true },
  wallet: { type: String, default: '0' },
  officeId: { type: String },
  cities: { type: Array, default: [] },
  role: { type: String, required: true },
  leads: { type: Array, default: [] },
  owner: { type: JSON, required: true },
  password: { type: String, required: true },
  hashPassword: { type: String, required: true }
});

const User = (module.exports = mongoose.model('User', UserSchema));

module.exports.addUser = (newUser, callback) => {
  newUser.save(callback);
};

module.exports.getUserByUsername = (username, callback) => {
  User.findOne({ username: username }, callback);
};

module.exports.getUserById = (id, callback) => {
  User.findById(id, callback);
};

module.exports.getUsers = callback => {
  User.find(callback);
};

module.exports.getSuperAdmin = callback => {
  User.findOne({ role: 'super-admin' }, callback);
};

module.exports.getCounsellors = callback => {
  User.find({ role: 'counsellor' }, callback);
};

module.exports.getManagers = callback => {
  User.find({ role: 'manager' }, callback);
};
module.exports.getManagersOfAdmin = (username, callback) => {
  User.find({ owner: { admin: username } }, callback);
};

module.exports.getAdmins = callback => {
  User.find({ role: 'admin' }, callback);
};

module.exports.deleteUser = (username, callback) => {
  User.deleteOne({ username: username }, callback);
};

module.exports.comparePassword = (candidatePassword, hash, callback) => {
  bcrypt.compare(candidatePassword, hash, (err, isMatch) => {
    if (err) throw err;
    callback(null, isMatch);
  });
};
