const express = require('express');
const router = express.Router();
const passport = require('passport');
const config = require('../config/database');
const FollowUpType = require('../models/follow-up-type');
const OldFollowupTypes = require('../models/old-follow-up-type');

// create followup type
router.post(
  '/createFollowUpType',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    FollowUpType.getFollowUpTypeByName(
      req.body.followUpType,
      (err, followUpType) => {
        if (err) {
          res.json({ success: false, msg: JSON.stringify(err) });
        } else {
          if (followUpType) {
            // // console.log(FollowUpType)
            return res.json({
              success: false,
              msg: `Follow Up type already exist.`,
              err: err
            });
          } else {
            let newFollowUpType = new FollowUpType({
              followUpType: req.body.followUpType,
              hasDueDate: req.body.hasDueDate,
              createdBy: req.body.user
            });

            FollowUpType.addFollowUpType(
              newFollowUpType,
              (err, followUpType) => {
                if (err) {
                  res.status(500).json({
                    success: false,
                    msg: 'Failed to add follow up type',
                    err: JSON.stringify(err)
                  });
                } else {
                  res.status(201).json({
                    success: true,
                    followUpType: followUpType,
                    msg: 'Follow Up Type Added'
                  });
                }
              }
            );
          }
        }
      }
    );
  }
);

// get followup types
router.get(
  '/getFollowUpTypes',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    FollowUpType.getFollowUpTypes((err, followuptypes) => {
      if (err) {
        res.json({
          success: false,
          msg: `Follow Up type already exist.`,
          err: err
        });
      } else {
        res.json({
          success: true,
          followuptypes: followuptypes,
          msg: 'Follow up types fetched.'
        });
      }
    });
  }
);

// delete followup types
router.post(
  '/deleteFollowUpTypes',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    FollowUpType.getFollowUpTypeByName(
      req.body.followUpType,
      (err, followUpType) => {
        if (err) {
          res.status(200).json({
            success: false,
            msg: 'Error occured',
            err: JSON.stringify(err)
          });
        } else {
          if (followUpType.canDelete) {
            let newfollowUpType = new OldFollowupTypes({
              followUpType: followUpType.followUpType,
              hasDueDate: followUpType.hasDueDate,
              createdBy: followUpType.createdBy,
              createdAt: followUpType.createdAt,
              updatedBy: req.body.username
            });
            OldFollowupTypes.addFollowUpType(
              newfollowUpType,
              (err, followUpType) => {
                if (err) {
                  res
                    .status(200)
                    .json({ success: false, msg: 'error occured', err: err });
                } else {
                  FollowUpType.deleteFollowUpType(
                    followUpType.followUpType,
                    (err, deletedfollowUpType) => {
                      if (err) {
                        res.status(200).json({
                          success: false,
                          msg: 'error occured',
                          err: err
                        });
                      } else {
                        res.status(200).json({
                          success: true,
                          msg: 'Followup type deleted',
                          followUpType: deletedfollowUpType
                        });
                      }
                    }
                  );
                }
              }
            );
          }
        }
      }
    );
  }
);

module.exports = router;
