const express = require('express');
const router = express.Router();
const config = require('../config/database');
const Package = require('../models/leadpackage');
const passport = require('passport');

// create package
router.post(
  '/createPackage',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    // // console.log(req.body.user);
    // // console.log(req.body.packageName);

    Package.getPackageByName(req.body.packageName, (err, package) => {
      if (err) {
        res.json({ success: false, msg: JSON.stringify(err) });
      } else {
        if (package) {
          return res.json({ success: false, msg: `Package already exist.` });
        } else {
          let newPackage = new Package({
            packageName: req.body.packageName,
            shortName: req.body.shortName,
            packageAmount: req.body.packageAmount,
            createdBy: req.body.user,
            purpose: req.body.purpose,
            profileLimit: req.body.profileLimit,
            source: req.body.source,
            serviceType: req.body.serviceType,
            cities: req.body.cities,
          });

          Package.addPackage(newPackage, (err, package) => {
            if (err) {
              // // console.log(err);
              res.status(500).json({
                success: false,
                msg: 'Failed to add Package',
                err: JSON.stringify(err)
              });
            } else {
              // // console.log(package)
              res.status(201).json({
                success: true,
                package: package,
                msg: 'Package is added'
              });
            }
          });
        }
      }
    });
  }
);

// get pacakges
router.get(
  '/getPackages',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Package.getPackage((err, packages) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'packages found', packages: packages });
      }
    });
  }
);

// get Field pacakges
router.post(
  '/getFieldPackages',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Package.getPackagesByFields(req.body.source, req.body.purpose, req.body.cities, (err, packages) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'packages found', packages: packages });
      }
    });
  }
);

// edit package
router.post(
  '/editPackage',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    Package.getPackageByName(req.body.packageName, (err, pack) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        if (pack) {
          pack.packageName = req.body.packageName;
          pack.packageAmount = req.body.packageAmount;
          Package.addPackage(pack, (err, pack) => {
            if (err) {
              res
                .status(200)
                .json({ success: false, msg: 'error occured', err: err });
            } else {
              res.status(200).json({
                success: true,
                msg: 'Package edit successful ',
                package: pack
              });
            }
          });
        } else {
          res.status(200).json({ success: false, msg: 'package not found' });
        }
      }
    });
  }
);

module.exports = router;
