const express = require('express');
const router = express.Router();
const passport = require('passport');
const config = require('../config/database');
const MemberType = require('../models/member-type');
const OldMemberType = require('../models/oldMemberTypes');

router.post(
  '/createMemberType',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    MemberType.getMemberByType(req.body.memberType, (err, memberType) => {
      if (err) {
        res.json({ success: false, msg: JSON.stringify(err) });
      } else {
        if (memberType) {
          return res.json({
            success: false,
            msg: `member-type already exist.`
          });
        } else {
          let newMemberType = new MemberType({
            memberType: req.body.memberType,
            createdBy: req.body.user
          });

          MemberType.addMemberType(newMemberType, (err, memberType) => {
            if (err) {
              res.status(500).json({
                success: false,
                msg: 'Failed to add member-type',
                err: JSON.stringify(err)
              });
            } else {
              res.status(201).json({
                success: true,
                memberType: memberType,
                msg: 'Member Type Added'
              });
            }
          });
        }
      }
    });
  }
);

router.get(
  '/getMemberTypes',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    MemberType.getMember((err, memberTypes) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'Error occured', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'member types found',
          types: memberTypes
        });
      }
    });
  }
);

// delete Member types
router.post(
  '/deleteMemberTypes',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    MemberType.getMemberByType(req.body.memberType, (err, memberType) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        let oldMemberType = new OldMemberType({
          memberType: memberType.memberType,
          createdBy: memberType.createdBy,
          createdAt: memberType.createdAt,
          updatedBy: req.body.username
        });
        OldMemberType.addMemberType(oldMemberType, (err, memberTypeAdded) => {
          if (err) {
            res.status(200).json({
              success: false,
              msg: 'error occured',
              err: JSON.stringify(err)
            });
          } else {
            MemberType.deleteMemberType(
              memberType,
              (err, deletedMemberType) => {
                if (err) {
                  res.status(200).json({
                    success: false,
                    msg: 'error occured',
                    err: JSON.stringify(err)
                  });
                } else {
                  res.status(200).json({
                    success: true,
                    msg: 'Member type deleted successfully',
                    memberType: deletedMemberType
                  });
                }
              }
            );
          }
        });
      }
    });
  }
);

module.exports = router;
