const _ = require('lodash');
const express = require('express');
const router = express.Router();
const bcrypt = require('bcryptjs');
const jwt = require('jsonwebtoken');
const passport = require('passport');
const User = require('../models/user');
const Office = require('../models/office');
const config = require('../config/database');
const OldProfile = require('../models/old-profile');

// get Office percentage by admin
router.get('/get-officePercentage/:admin', (req, res) => {
  // console.log(req.params.admin);
  User.getUserByUsername(req.params.admin, (err, user) => {
    if (err) {
      res.status(200).json({ success: false, msg: 'error occured', err: err });
    } else {
      if (user) {
        if (user.officeId) {
          Office.getOfficeById(user.officeId, (err, office) => {
            if (office) {
              res.status(200).json({
                success: true,
                msg: 'office percentage found',
                per: office.officePercentage,
                officeId: office._id
              });
            } else {
              res
                .status(200)
                .json({ success: false, msg: 'office does not found' });
            }
          });
        } else {
          res
            .status(200)
            .json({ success: false, msg: 'User does not contain office id' });
        }
      } else {
        res.status(200).json({ success: false, msg: 'User not found' });
      }
    }
  });
});

// get counsellors
router.get(
  '/getCounsellors',
  (req, res) => {
    let counsellors = [];
    User.getCounsellors((err, counsellors) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'Counsellors found',
          counsellors: counsellors
        });
      }
    });
  }
);

// get counsellors by username
router.get(
  '/getCounsellors/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let counsellors = [];
    let username = req.params.username;
    User.getCounsellorsOf(username, (err, counsellors) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'Counsellors found',
          counsellors: counsellors
        });
      }
    });
  }
);

// get managers
router.get(
  '/getManagers',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let managers = [];
    User.getManagers((err, managers) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'managers found', managers: managers });
      }
    });
  }
);

// get manager by username
router.get(
  '/getManagers/:username',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    let managers = [];
    let username = req.params.username;
    User.getManagersOfAdmin(username, (err, managers) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res
          .status(200)
          .json({ success: true, msg: 'managers found', managers: managers });
      }
    });
  }
);

// get admins
router.get(
  '/getAdmins',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    User.getAdmins((err, admins) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        res.status(200).json({
          success: true,
          msg: 'Admins found',
          admins: admins
        });
      }
    });
  }
);

router.get('/get-user/:username', (req, res) => {
  User.getUserByUsername(req.params.username, (err, user) => {
    if (err) {
      res.status(200).json({ success: false, msg: 'error occured', err: err });
    } else {
      if (user) {
        res.status(200).json({ success: true, msg: 'User found', user: user });
      } else {
        res.status(200).json({ success: false, msg: 'User Not found' });
      }
    }
  });
});

router.get('/getofficeId/:username', (req, res) => {
  User.getUserByUsername(req.params.username, (err, user) => {
    if (err) {
      res.status(200).json({ success: false, msg: 'error occured', err: err });
    } else {
      if (user) {
        res
          .status(200)
          .json({ success: true, msg: 'Office Id found', id: user.officeId });
      } else {
        res.status(200).json({ success: false, msg: 'officeId Not found' });
      }
    }
  });
});

//   username: { type: String, required: true },
//   name: { type: String, required: true },
//   gender: { type: String, required: true },
//   wallet: { type: JSON },
//   officeId: { type: String },
//   cities: { type: Array, default: [] },
//   role: { type: String, required: true },
//   leads: { type: Array, default: [] },
//   owner: { type: JSON, required: true },
//   password: { type: String, required: true },
//   hashPassword:

// edit user
router.post(
  '/edit-user',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    User.getUserByUsername(req.body.username, (err, user) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        if (user) {
          let newObj = new OldProfile({
            username: user.username,
            name: user.name,
            gender: user.gender,
            wallet: user.wallet,
            officeId: user.officeId,
            cities: user.cities,
            role: user.role,
            leads: user.leads,
            owner: user.owner,
            password: user.password,
            hashPassword: user.hashPassword
          });
          OldProfile.addProfile(newObj, (err, profile) => {
            if (err) {
              res
                .status(200)
                .json({ success: false, msg: 'Error occured', err: err });
            } else {
              if (profile) {
                console.log(profile);
                user.name = req.body.name;
                User.addUser(user, (err, user) => {
                  if (err) {
                    res
                      .status(200)
                      .json({ success: false, msg: 'error occured', err: err });
                  } else {
                    OldProfile.getProfiles((err, profiles) => {
                      console.log(profiles);
                    });
                    res.status(200).json({
                      success: true,
                      msg: 'User edit successful.',
                      user: user
                    });
                  }
                });
              } else {
                res
                  .status(200)
                  .json({ success: false, msg: 'error in updating profile' });
              }
            }
          });
        } else {
          res.status(200).json({ success: false, msg: 'user not found' });
        }
      }
    });
  }
);

// update Password
router.post(
  '/change-password',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    console.log(req.body.username);
    User.getUserByUsername(req.body.username, (err, user) => {
      if (err) {
        res.status(200).json({
          success: false,
          msg: 'Error in changing password',
          err: err
        });
      } else {
        if (user) {
          User.comparePassword(
            req.body.currentPassword,
            user.hashPassword,
            (err, isMatch) => {
              if (err) {
                res.status(200).json({
                  success: false,
                  msg: 'Error in current checking password',
                  err: err
                });
              } else {
                if (isMatch) {
                  bcrypt.hash(req.body.newPassword, 10, (err, hash) => {
                    if (err) {
                      return res.status(200).json({
                        success: false,
                        msg: 'Error hashing password'
                      });
                    }

                    user.password = req.body.newPassword;
                    user.hashPassword = hash;

                    User.addUser(user, (err, user) => {
                      if (err) {
                        res.status(500).json({
                          success: false,
                          msg: 'Failed to update password',
                          err: JSON.stringify(err)
                        });
                      } else {
                        res
                          .status(201)
                          .json({ success: true, msg: 'password updated' });
                      }
                    });
                  });
                } else {
                  res.status(200).json({
                    success: true,
                    msg: 'Your current password is incorrect'
                  });
                }
              }
            }
          );
        } else {
          res.status(200).json({ success: false, msg: 'user not found' });
        }
      }
    });
  }
);

// create user
router.post(
  '/createUser',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    User.getUserByUsername(req.body.username, (err, user) => {
      if (err) {
        res.json({ success: false, msg: JSON.stringify(err) });
      } else {
        if (user) {
          return res.json({ success: false, msg: `username already exist.` });
        } else {
          bcrypt.hash(req.body.password, 10, (err, hash) => {
            if (err) {
              return res
                .status(200)
                .json({ success: false, msg: 'Error hashing password' });
            }
            let newUser = new User({
              username: req.body.username,
              name: req.body.name,
              password: req.body.password,
              role: req.body.role,
              cities: req.body.city,
              gender: req.body.gender,
              owner: req.body.owner,
              hashPassword: hash,
              officeId: req.body.officeId
            });

            User.addUser(newUser, (err, user) => {
              if (err) {
                res.status(500).json({
                  success: false,
                  msg: 'Failed to add user',
                  err: JSON.stringify(err)
                });
              } else {
                res
                  .status(201)
                  .json({ success: true, user: user, msg: 'user Added' });
              }
            });
          });
        }
      }
    });
  }
);

// login
router.post('/login', (req, res) => {
  const username = req.body.username;
  const password = req.body.password;
  // console.log(username, password);
  User.getUserByUsername(req.body.username, (err, user) => {
    if (err) {
      res.status(200).json({ success: false, msg: 'error occured', err: err });
    } else {
      if (user) {
        User.comparePassword(password, user.hashPassword, (err, isMatch) => {
          if (err) {
            // console.log(err);
            res
              .status(200)
              .json({ success: false, msg: 'error occured', err: err });
          }
          if (isMatch) {
            var t_user = {
              id: user._id,
              name: user.name,
              username: user.username,
              owner: user.owner,
              gender: user.gender,
              role: user.role
            };
            const token = jwt.sign(t_user, config.secret, {
              expiresIn: 604800
            });
            res.status(200).json({
              success: true,
              msg: 'Welcome ' + user.name,
              token: 'JWT ' + token,
              user: {
                id: user._id,
                name: user.name,
                username: user.username,
                owner: user.owner,
                gender: user.gender,
                role: user.role,
                officeId: user.officeId,
                wallet: user.wallet
              }
            });
          } else {
            res.status(200).json({ success: false, msg: 'wrong password' });
          }
        });
      } else {
        res.status(200).json({ success: false, msg: 'User not found' });
      }
    }
  });
});

// delete user
router.post(
  '/deleteUser',
  passport.authenticate('jwt', { session: false }),
  (req, res) => {
    User.getUserByUsername(req.body.username, (err, user) => {
      if (err) {
        res
          .status(200)
          .json({ success: false, msg: 'error occured', err: err });
      } else {
        if (user) {
          let oldUser = new OldUser({
            name: user.name,
            username: user.username,
            gender: user.gender,
            city: user.city,
            state: user.state,
            role: user.role,
            owner: user.owner,
            password: user.password,
            hashPassword: user.hashPassword
          });
          OldUser.addUser(olduser, (err, olduser) => {
            if (err) {
              res
                .status(200)
                .json({ success: false, msg: 'error occured', err: err });
            } else {
              User.deleteUser(req.body.username, (err, user) => {
                if (err) {
                  res
                    .status(200)
                    .json({ success: false, msg: 'error occured', err: err });
                } else {
                  res.status(200).json({
                    success: true,
                    msg: 'user deleted successfully..',
                    user: user
                  });
                }
              });
            }
          });
        } else {
          res.status(200).json({ success: false, msg: 'User not found' });
        }
      }
    });
  }
);

module.exports = router;
