const express = require('express');
const mongoose = require('mongoose');
const cors = require('cors');
const bodyParser = require('body-parser');
const config = require('./config/database');
const passport = require('passport');

mongoose.connect(config.database, {
  useNewUrlParser: true,
  autoIndex: false
});

mongoose.connection.on('connected', () => {
  console.log('connected to db ' + config.database);
});

mongoose.connection.on('error', err => {
  console.log('database error:' + err);
});

const app = express();
app.use(cors());

// passport
app.use(passport.initialize());
app.use(passport.session());
require('./config/passport')(passport);
// passport end


// parse application/x-www-form-urlencoded
// Body Parser Middleware
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));

const newLead = require('./routes/leads');
const file = require('./routes/file');
app.use('/leads', newLead);
app.use('/file', file);

// app.use(
  //   bodyParser.urlencoded({
    //     extended: true
    //   })
    // );
    // app.use(bodyParser.json({ limit: '50mb' }));
    // app.use(bodyParser.urlencoded({ limit: '50mb', extended: true }));
    // app.use(bodyParser.json());
    
    app.get('/', (req, res) => {
      res.send('Root Ankur');
    });
    
    const user = require('./routes/users');
    const office = require('./routes/offices');
    const member = require('./routes/members');
    const memberType = require('./routes/member-types');
    const followUpType = require('./routes/followUpTypes');
    const officePackage = require('./routes/office-packages');
    const remainder = require('./routes/remainders');
    const cities = require('./routes/cities');
    const states = require('./routes/states');
    const request = require('./routes/requests');
    const approvedRequest = require('./routes/approvedRequests');
    const leadpackage = require('./routes/leadpackages');
    const purposes = require('./routes/purposes');
    const sources = require('./routes/sources');
    
app.use('/approvedrequests', approvedRequest);
app.use('/requests', request);
app.use('/remainders', remainder);
app.use('/officepackages', officePackage);
app.use('/followuptypes', followUpType);
app.use('/membertypes', memberType);
app.use('/packages', leadpackage);
app.use('/members', member);
app.use('/office', office);
app.use('/cities', cities);
app.use('/states', states);
app.use('/user', user);
app.use('/purposes', purposes);
app.use('/sources', sources);

port = 3400;
host = '0.0.0.0';

app.listen(port, host, () => {
  console.log('Server is running in port: ' + port);
});
